==> OpenInteract-1.99_00.tar.gz: base-2.02/OpenInteract2/Action/Package.pm <==
package OpenInteract2::Action::Package;

# $Id: Package.pm,v 1.5 2003/06/04 15:47:00 lachoy Exp $

use strict;
use base qw( OpenInteract2::Action );
use OpenInteract2::Constants qw( :log );
use OpenInteract2::Context   qw( DEBUG LOG CTX );

$OpenInteract2::Action::Package::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);

sub listing {
    my ( $self ) = @_;
    return $self->generate_content(
                    { packages => CTX->repository->fetch_all_packages() },
                    { name => 'base::package_listing' } );
}


sub show {
    my ( $self ) = @_;
    my $repository = CTX->repository;
    my $pkg = $self->param( 'package' );
    $pkg = undef unless ( ref $pkg eq 'OpenInteract2::Package' );
    unless ( $pkg ) {
        my $name = CTX->request->param( 'name' );
        $pkg = $repository->fetch_package_by_name({ name => $name });
        unless ( $pkg ) {
            LOG( LWARN, "Failed to find package [$name]" );
            my $error_msg = "Could not find package with name [$name]";
            $self->param_add( error_msg => $error_msg );
            return $self->execute({ task => 'listing' });
        }
    }
    return $self->generate_content( { pkg => $pkg },
                                    { name => 'base::package_detail' } );
}

1;

__END__

=head1 NAME

OpenInteract2::Action::Package - View package information

=head1 DESCRIPTION

This handler simply displays information about packages in the website
repository.

=head1 TASKS

=head2 listing

Lists the packages in the current website package repository.

B<Action Parameters>

standard

B<Request Parameters>

none

=head2 show

Displays details for a single package.

B<Action Parameters>

=over 4

=item B<package>

Display this package if specified. Must be a
L<OpenInteract2::Package|OpenInteract2::Package> object.

=back

B<Request Parameters>

=over 4

=item B<name>

Name of the package you want to display.

=back

=head1 COPYRIGHT

Copyright (c) 2001-2002 Chris Winters. All rights reserved.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHORS

Chris Winters E<lt>chris@cwinters.comE<gt>

==> OpenInteract-1.99_03.tar.gz: base-2.05/OpenInteract2/Action/Package.pm <==
package OpenInteract2::Action::Package;

# $Id: Package.pm,v 1.7 2003/06/25 14:10:48 lachoy Exp $

use strict;
use base qw( OpenInteract2::Action );
use Log::Log4perl            qw( get_logger );
use OpenInteract2::Constants qw( :log );
use OpenInteract2::Context   qw( CTX );

$OpenInteract2::Action::Package::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);

sub listing {
    my ( $self ) = @_;
    return $self->generate_content(
                    { packages => CTX->repository->fetch_all_packages() },
                    { name => 'base::package_listing' } );
}


sub show {
    my ( $self ) = @_;
    my $log = get_logger( LOG_APP );
    my $repository = CTX->repository;
    my $pkg = $self->param( 'package' );
    $pkg = undef unless ( ref $pkg eq 'OpenInteract2::Package' );
    unless ( $pkg ) {
        my $name = CTX->request->param( 'name' );
        $pkg = $repository->fetch_package_by_name({ name => $name });
        unless ( $pkg ) {
            $log->warn( "Failed to find package [$name]" );
            my $error_msg = "Could not find package with name [$name]";
            $self->param_add( error_msg => $error_msg );
            return $self->execute({ task => 'listing' });
        }
    }
    return $self->generate_content( { pkg => $pkg },
                                    { name => 'base::package_detail' } );
}

1;

__END__

=head1 NAME

OpenInteract2::Action::Package - View package information

=head1 DESCRIPTION

This handler simply displays information about packages in the website
repository.

=head1 TASKS

=head2 listing

Lists the packages in the current website package repository.

B<Action Parameters>

standard

B<Request Parameters>

none

=head2 show

Displays details for a single package.

B<Action Parameters>

=over 4

=item B<package>

Display this package if specified. Must be a
L<OpenInteract2::Package|OpenInteract2::Package> object.

=back

B<Request Parameters>

=over 4

=item B<name>

Name of the package you want to display.

=back

=head1 COPYRIGHT

Copyright (c) 2001-2003 Chris Winters. All rights reserved.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHORS

Chris Winters E<lt>chris@cwinters.comE<gt>
